mysql.connection._Statement_Cleaner

Package mysql :: Module connection :: Class _Statement_Cleaner |
[hide private]
[frames] | no frames]

# Class _Statement_Cleaner

    object --+
             |
            _Statement_Cleaner

Statement cleaning object.

This object is responsible for freeing unused Statement objects.

References to the statement objects are kept in this external object because we cannot keep it in the Connection object. Because the Connection and Statement object are involved in a cycle, they need a neutral third-party to hold references to the statement objects and free them appropriately.

Instance Methods | [hide private]
`` | __init__(...) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e068>`

Instance Variables | [hide private]
`` | _statement_list List of MYSQL_STMT structures (wrapped in PyCObject objects).

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(...) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: object.__new__

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e068>

Instance Variable Details | [hide private]

### _statement_list List of MYSQL_STMT structures (wrapped in PyCObject objects).